Use node moduleResolution everywhere (#47687)

TestRunner was already using it, but upstream projects (e.g. Compiler) were not, causing TestRunner to re-parse and re-bind all upstream files in (at least) editor scenarios), slowing down initial project load.

In local testing, this cut a find-all-refs call in checker.ts from 5s to 2.5s.
This commit is contained in:
Andrew Casey authored and GitHub committed 2022-02-01 15:59:59 -08:00
1 parent 2172e1964f
commit 7cc0f755ce
2 files changed
+1 -2

No files matched your search

-1
View File
@@ -2,7 +2,6 @@
"extends": "../tsconfig-noncomposite-base",
"compilerOptions": {
"outFile": "../../built/local/run.js",
"moduleResolution": "node",
"composite": false,
"declaration": false,
"declarationMap": false,
+1 -1
View File
@@ -3,7 +3,7 @@
"pretty": true,
"lib": ["es2015.iterable", "es2015.generator", "es5"],
"target": "es5",
"moduleResolution": "classic",
"moduleResolution": "node",
"rootDir": ".",
"declaration": true,